
=======
Stimela
=======


|Pypi Version|
|Build Version|  



`Documentation <https://github.com/SpheMakh/Stimela/wiki>`_  
==============

`Installation <https://github.com/SpheMakh/Stimela/wiki/Installation>`_
==============

`Tutorials <https://github.com/SpheMakh/Stimela/wiki/Examples>`_
===========


This project was initially funded by the `SKA/AWS AstroCompute In The Cloud <https://www.skatelescope.org/ska-aws-astrocompute-call-for-proposals>`_ initiative.


.. |Pypi Version| image:: https://img.shields.io/pypi/v/stimela.svg
                  :target: https://pypi.python.org/pypi/stimela
                  :alt:
.. |Build Version| image:: https://travis-ci.org/SpheMakh/Stimela.svg?branch=master
                  :target: https://travis-ci.com/Sphemakh/Stimela/
                  :alt:

.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/stimela.svg
                     :target: https://pypi.python.org/pypi/stimela
                     :alt:
